@@ -14,18 +14,16 @@
  * SOFTWARE.
  */
 
-extern crate dmntk_common;
-extern crate dmntk_feel;
+extern crate dmntk_examples;
+extern crate dmntk_feel_parser;
 extern crate roxmltree;
 
+use crate::model::Definitions;
+use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+
 pub mod model;
 
-pub use model::parser::parse;
-
-#[cfg(test)]
-mod tests {
-  #[test]
-  fn it_works() {
-    assert_eq!(2 + 2, 4);
-  }
+/// Parses the XML document containing definitions.
+pub fn parse(xml: &str, source: &str) -> Result<Definitions> {
+  crate::model::parser::ModelParser::default().parse(xml, source)
 }
