@@ -23,8 +23,8 @@ pub(crate) mod parser;
 mod tests;
 
 use self::errors::*;
-use dmntk_common::{DmntkError, HRef, OptHRef, Result};
-use dmntk_feel::{FeelType, Name};
+use dmntk_feel_parser::dmntk_feel::dmntk_common::{DmntkError, HRef, OptHRef, Result};
+use dmntk_feel_parser::dmntk_feel::{FeelType, Name};
 use std::convert::TryFrom;
 
 /// [Element] represents an element from another metamodel.
@@ -255,6 +255,7 @@ pub enum DrgElement {
   InputData(InputData),
   BusinessKnowledgeModel(BusinessKnowledgeModel),
   DecisionService(DecisionService),
+  KnowledgeSource(KnowledgeSource),
 }
 
 impl DrgElement {
@@ -269,6 +270,7 @@ impl DrgElement {
       DrgElement::InputData(inner) => inner.id().as_ref().map_or(false, |v| v == id),
       DrgElement::BusinessKnowledgeModel(inner) => inner.id().as_ref().map_or(false, |v| v == id),
       DrgElement::DecisionService(inner) => inner.id().as_ref().map_or(false, |v| v == id),
+      DrgElement::KnowledgeSource(inner) => inner.id().as_ref().map_or(false, |v| v == id),
     }
   }
   /// Checks if this [DrgElement] has a specified name.
@@ -278,10 +280,11 @@ impl DrgElement {
   /// Otherwise returns [false].
   pub fn has_name(&self, name: &str) -> bool {
     match self {
-      DrgElement::Decision(inner) => inner.name() == name,
-      DrgElement::InputData(inner) => inner.name() == name,
-      DrgElement::BusinessKnowledgeModel(inner) => inner.name() == name,
-      DrgElement::DecisionService(inner) => inner.name() == name,
+      DrgElement::Decision(inner) => inner.name().eq(name),
+      DrgElement::InputData(inner) => inner.name().eq(name),
+      DrgElement::BusinessKnowledgeModel(inner) => inner.name().eq(name),
+      DrgElement::DecisionService(inner) => inner.name().eq(name),
+      DrgElement::KnowledgeSource(inner) => inner.name().eq(name),
     }
   }
   /// Returns `true` when this [DrgElement] is an instance of [Decision].
@@ -300,6 +303,10 @@ impl DrgElement {
   pub fn is_decision_service(&self) -> bool {
     matches!(self, DrgElement::DecisionService(_))
   }
+  /// Returns `true` when this [DrgElement] is an instance of [KnowledgeSource].
+  pub fn is_knowledge_source(&self) -> bool {
+    matches!(self, DrgElement::KnowledgeSource(_))
+  }
 }
 
 /// [Expression] is an abstract class that describes the logic
@@ -494,6 +501,18 @@ impl Definitions {
       .filter_map(|v| if let DrgElement::InputData(input_data) = v { Some(input_data) } else { None })
       .collect::<Vec<&InputData>>()
   }
+  /// Returns an optional reference to [KnowledgeSource] with specified identifier
+  /// or [None] when such [KnowledgeSource] was not found among instances of [DrgElements](DrgElement)).
+  pub fn knowledge_source_by_id(&self, id: &str) -> Option<&KnowledgeSource> {
+    self.drg_elements.iter().find_map(|v| {
+      if v.is_knowledge_source() && v.has_id(id) {
+        if let DrgElement::KnowledgeSource(input_data) = v {
+          return Some(input_data);
+        }
+      }
+      None
+    })
+  }
   /// Returns reference to the container of instances of [BusinessContextElement] contained in this [Definitions].
   pub fn business_context_elements(&self) -> &Vec<BusinessContextElementInstance> {
     &self.business_context_elements
@@ -1110,9 +1129,58 @@ impl DmnElement for AuthorityRequirement {
 }
 
 /// The class [KnowledgeSource] is used to model authoritative knowledge sources in a decision model.
-/// In a DRD, an instance of [KnowledgeSource] is represented by a knowledge source diagram element.
+/// In a DRD, an instance of [KnowledgeSource] is represented by a `knowledge source` diagram element.
 #[derive(Debug, Clone)]
-pub struct KnowledgeSource;
+pub struct KnowledgeSource {
+  /// Optional identifier of this this [KnowledgeSource].
+  id: Option<String>,
+  /// Optional description of this [KnowledgeSource].
+  description: Option<String>,
+  /// Optional alternative short description of this [KnowledgeSource].
+  label: Option<String>,
+  /// Container to attach additional elements to any [KnowledgeSource].
+  extension_elements: Option<ExtensionElement>,
+  /// Container to attach named extended attributes and model associations to any [KnowledgeSource].
+  extension_attributes: Vec<ExtensionAttribute>,
+  /// Name of this [KnowledgeSource].
+  name: String,
+  /// Optional `FEEL` name of this [KnowledgeSource].
+  feel_name: Option<Name>,
+}
+
+impl DmnElement for KnowledgeSource {
+  /// Returns reference to optional identifier for this [KnowledgeSource].
+  fn id(&self) -> &Option<String> {
+    &self.id
+  }
+  /// Returns reference to optional description of this [KnowledgeSource].
+  fn description(&self) -> &Option<String> {
+    &self.description
+  }
+  /// Returns reference to optional alternative short description of this [KnowledgeSource].
+  fn label(&self) -> &Option<String> {
+    &self.label
+  }
+  /// Returns reference to attached additional elements to any [KnowledgeSource].
+  fn extension_elements(&self) -> &Option<ExtensionElement> {
+    &self.extension_elements
+  }
+  /// Returns reference to attached named extended attributes and model associations to any [KnowledgeSource].
+  fn extension_attributes(&self) -> &Vec<ExtensionAttribute> {
+    &self.extension_attributes
+  }
+}
+
+impl NamedElement for KnowledgeSource {
+  /// Returns reference to the name of this [KnowledgeSource].
+  fn name(&self) -> &str {
+    &self.name
+  }
+  /// Returns a reference to optional `FEEL` name of this [KnowledgeSource].
+  fn feel_name(&self) -> &Option<Name> {
+    &self.feel_name
+  }
+}
 
 /// `Invocable` is used to model the inputs of a decision whose values
 /// are defined outside of the decision model.
@@ -2166,7 +2234,7 @@ pub enum DcKnownColor {
 }
 
 mod errors {
-  use dmntk_common::DmntkError;
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
 
   /// Errors related to the model.
   #[derive(Debug, PartialEq)]
